# -*- coding: utf-8 -*-
"""
Created on Mon Dec 16 13:17:14 2013

@author: Job Verkaik, HKV Lijn in water
"""
# Repository path:    $HeadURL: https://90.145.156.222/DMS-Houtribdijk/FEWS/Modules/Waterlevels/waterlevels/FewsLogger.py $
# Last committed:     $Revision: 299106 $; $Author: svcdms $; $Date: 2019-08-30 13:12:33 +0200 (vr, 30 aug 2019) $

from datetime import datetime


class Logger:
    "Class implementing a logger for the Delft-FEWS general adapter"
    def __init__(self,fp):
        "open the log file"
        self._filepath = fp
        self._messages = []
        try:
            self._logfile = open(self._filepath, 'w')
        except IOError:
            print ("Could not open file %s" % self._filepath)
            
        self._logfile.write("""<?xml version="1.0" encoding="utf-8"?>\n<Diag xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://www.wldelft.nl/fews/PI http://fews.wldelft.nl/schemas/version1.0/pi-schemas/pi_diag.xsd" version="1.2" xmlns="http://www.wldelft.nl/fews/PI">\n""")
        
    def write(self,level,message):
        "store the messages"
        # LOG LEVELS:
        # 1: ERROR
        # 2: WARNING
        # 3: INFO
        # 4: DEBUG
        dt = datetime.utcnow().strftime('%Y-%m-%d %H:%M:%S.%f')[:-3]
        mess = """\t<line level=\"%d\" description=\"%s - %s\"/>\n""" % (level, dt, message)
        self._logfile.write(mess)

    def debug(self, message):
        self.write(4, message)

    def info(self, message):
        self.write(3, message)

    def warning(self, message):
        self.write(2, message)

    def error(self, message):
        self.write(1, message)

    def close(self):
        "close the diagnostics file"
        self._logfile.write("""</Diag>""")
        self._logfile.close()
